pub struct InnerArc<Outer, Inner> {
outer: Outer,
elem: *const Inner,
}Fields
outer: Outerelem: *const InnerImplementations
Sourceimpl<Outer, Inner> InnerArc<Outer, Inner>
impl<Outer, Inner> InnerArc<Outer, Inner>
Sourcepub unsafe fn new<Arced, Err>(
outer: &Outer,
arc: impl FnOnce(&Outer) -> &Arc<Arced>,
get: impl FnOnce(&Arced) -> Result<&Inner, Err>,
) -> Result<Self, Err>where
Outer: Clone,
pub unsafe fn new<Arced, Err>(
outer: &Outer,
arc: impl FnOnce(&Outer) -> &Arc<Arced>,
get: impl FnOnce(&Arced) -> Result<&Inner, Err>,
) -> Result<Self, Err>where
Outer: Clone,
Safety
Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around.
Sourcepub unsafe fn inherit<NewInner, Err>(
&self,
get: impl FnOnce(&Inner) -> Result<&NewInner, Err>,
) -> Result<InnerArc<Outer, NewInner>, Err>where
Outer: Clone,
pub unsafe fn inherit<NewInner, Err>(
&self,
get: impl FnOnce(&Inner) -> Result<&NewInner, Err>,
) -> Result<InnerArc<Outer, NewInner>, Err>where
Outer: Clone,
Safety
Sourcepub unsafe fn new_from_outer<Err>(
outer: &Outer,
get: impl FnOnce(&Outer) -> Result<&Inner, Err>,
) -> Result<Self, Err>where
Outer: Clone,
pub unsafe fn new_from_outer<Err>(
outer: &Outer,
get: impl FnOnce(&Outer) -> Result<&Inner, Err>,
) -> Result<Self, Err>where
Outer: Clone,
Safety
Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around and the provided reference is actually behind the Arc.
Sourcepub unsafe fn new_owned_infallible<'a, Arced>(
outer: Outer,
arc: impl FnOnce(&Outer) -> &Arc<Arced>,
get: impl FnOnce(&Arced) -> &'a Inner,
) -> Selfwhere
Outer: Clone + 'a,
Inner: 'a,
pub unsafe fn new_owned_infallible<'a, Arced>(
outer: Outer,
arc: impl FnOnce(&Outer) -> &Arc<Arced>,
get: impl FnOnce(&Arced) -> &'a Inner,
) -> Selfwhere
Outer: Clone + 'a,
Inner: 'a,
Safety
Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around, and the provided reference is actually behind the Arc.
pub const fn outer(&self) -> &Outer